
From: Jeffrey Mahoney <jeffm@suse.com>

This patch changes reiserfs to use the VFS level private inode flags, and
eliminates the old reiserfs private inode flag.

Signed-off-by: Jeff Mahoney <jeffm@suse.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/include/linux/reiserfs_fs_i.h  |    5 ++---
 25-akpm/include/linux/reiserfs_xattr.h |    4 ++--
 2 files changed, 4 insertions(+), 5 deletions(-)

diff -puN include/linux/reiserfs_fs_i.h~reiserfs-change-reiserfs-to-use-s_private include/linux/reiserfs_fs_i.h
--- 25/include/linux/reiserfs_fs_i.h~reiserfs-change-reiserfs-to-use-s_private	2005-03-07 20:41:24.000000000 -0800
+++ 25-akpm/include/linux/reiserfs_fs_i.h	2005-03-07 20:41:24.000000000 -0800
@@ -23,9 +23,8 @@ typedef enum {
       space on crash with some files open, but unlinked. */
     i_link_saved_unlink_mask   =  0x0010,
     i_link_saved_truncate_mask =  0x0020,
-    i_priv_object              =  0x0080,
-    i_has_xattr_dir            =  0x0100,
-    i_data_log	               =  0x0200,
+    i_has_xattr_dir            =  0x0040,
+    i_data_log	               =  0x0080,
 } reiserfs_inode_flags;
 
 
diff -puN include/linux/reiserfs_xattr.h~reiserfs-change-reiserfs-to-use-s_private include/linux/reiserfs_xattr.h
--- 25/include/linux/reiserfs_xattr.h~reiserfs-change-reiserfs-to-use-s_private	2005-03-07 20:41:24.000000000 -0800
+++ 25-akpm/include/linux/reiserfs_xattr.h	2005-03-07 20:41:24.000000000 -0800
@@ -31,7 +31,7 @@ struct reiserfs_xattr_handler {
 
 
 #ifdef CONFIG_REISERFS_FS_XATTR
-#define is_reiserfs_priv_object(inode) (REISERFS_I(inode)->i_flags & i_priv_object)
+#define is_reiserfs_priv_object(inode) IS_PRIVATE(inode)
 #define has_xattr_dir(inode) (REISERFS_I(inode)->i_flags & i_has_xattr_dir)
 ssize_t reiserfs_getxattr (struct dentry *dentry, const char *name,
 			   void *buffer, size_t size);
@@ -106,7 +106,7 @@ reiserfs_read_unlock_xattr_i(struct inod
 static inline void
 reiserfs_mark_inode_private(struct inode *inode)
 {
-    REISERFS_I(inode)->i_flags |= i_priv_object;
+    inode->i_flags |= S_PRIVATE;
 }
 
 #else
_
